export interface Exec {
    /**
     * Executes a command.
     *
     * @param cmd The command to execute.
     * @param args The arguments of the command to execute.
     * @returns A promise that will resolve once the command finishes.
     */
    (cmd: string, args: string[]): Promise<ExecResult>;
    /**
     * Streams the result of a command if `stream` is specified in the `options` parameter.
     *
     * Specify the `stream` if the output of your command is too long or if you need to stream things indefinitely (for example container logs).
     *
     * @param cmd The command to execute.
     * @param args The arguments of the command to execute.
     * @param options The list of options.
     * @param options.stream Provides three functions: `onOutput` (invoked every time `stdout` or `stderr` is received), `onError` and `onClose` (invoked when the stream has ended).
     */
    (cmd: string, args: string[], options: {
        stream: {
            onOutput?: (data: {
                stdout: string;
            } | {
                stderr: string;
            }) => void;
            onError?: (error: any) => void;
            onClose?: (exitCode: number) => void;
        };
    }): void;
}
export interface ExecResult extends RawExecResult {
    /**
     * Split output lines.
     * @returns The list of lines.
     */
    lines(): string[];
    /**
     * Parse each output line as a JSON object.
     * @returns The list of lines where each line is a JSON object.
     */
    parseJsonLines(): any[];
    /**
     * Parse a well formed JSON output.
     * @returns The JSON object.
     */
    parseJsonObject(): any;
}
export interface RawExecResult {
    readonly cmd?: string;
    readonly killed?: boolean;
    readonly signal?: string;
    readonly code?: number;
    readonly stdout: string;
    readonly stderr: string;
}
